California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 013 - AB 48 (CHAPTER 530, STATUTES OF 2019), O'DONNELL. EDUCATION FINANCE: SCHOOL FACILITIES: PUBLIC PRESCHOOL, K-12, AND COLLEGE HEALTH AND SAFETY BOND ACT OF 2020 View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1425124 | HUITT-ZOLLARS INC FEDERAL PAC (FED PAC ID #C00543710) YES ON PROPOSITION 13 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1424666 | O'DONNELL BALLOT MEASURE COMMITTEE; CITIZENS FOR A STRONG ECONOMY & SAFE SCHOOLS, PATRICK | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1220380 | COMMUNITY COLLEGE FACILITY COALITION ISSUES COMMITTEE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1421743 | CALIFORNIANS FOR QUALITY SCHOOLS, SPONSORED BY THE CALIFORNIA BUILDING INDUSTRY ASSOCIATION - YES ON PROP 13 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
980478 | COALITION FOR ADEQUATE SCHOOL HOUSING ISSUES COMMITTEE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1337625 | YES ON PROPOSITION 13 - CALIFORNIA COALITION FOR PUBLIC HIGHER EDUCATION ISSUES COMMITTEE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1421558 | NEWSOM, TEACHERS, NURSES, AND FIREFIGHTERS; CALIFORNIANS FOR SAFE SCHOOLS AND HEALTHY LEARNING, YES ON PROP 13, A COMMITTEE SUPPORTED BY GOVERNOR | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1425372 | CALIFORNIA CHARTER SCHOOLS ASSOCIATION, AN IRC 501 (C) (3) ORGANIZATION IN SUPPORT OF CALIFORNIA PROPOSITION 13 | SUPPORT